RetrievalError

Enum RetrievalError 

#[non_exhaustive]
pub enum RetrievalError {
Show 17 variants EmptyDocumentId, EmptyDocumentText { id: DocumentId, }, EmptyQuery, ZeroLimit, EmptyEmbedding, NonFiniteEmbedding { index: usize, }, EmbeddingCoordinateOutOfRange { index: usize, }, ZeroNormEmbedding, DimensionMismatch { expected: usize, actual: usize, }, EmbeddingCountMismatch { expected: usize, actual: usize, }, EmptyEmbeddingInput { index: usize, }, DuplicateDocument(DocumentId), CapabilityDenied { name: String, }, Cancelled, DeadlineExceeded, Provider { message: String, }, UsageOverflow,
}
Failure at a provider-neutral embedding or retrieval boundary.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


EmptyDocumentId

A document identity was empty.



EmptyDocumentText

A document contained no usable text.

Fields

id: DocumentId

Invalid document identity.



EmptyQuery

A query contained no usable text.



ZeroLimit

A query requested no results.



EmptyEmbedding

An embedding contained no dimensions.



NonFiniteEmbedding

An embedding contained a non-finite coordinate.

Fields

index: usize

Zero-based invalid coordinate.



EmbeddingCoordinateOutOfRange

An embedding coordinate exceeded a backend numeric representation.

Fields

index: usize

Zero-based invalid coordinate.



ZeroNormEmbedding

Cosine similarity is undefined for a zero vector.



DimensionMismatch

Embeddings with different dimensions cannot share an index.

Fields

expected: usize

Index or batch dimension.

actual: usize

Received dimension.



EmbeddingCountMismatch

A provider returned a different number of vectors than inputs.

Fields

expected: usize

Input count.

actual: usize

Returned vector count.



EmptyEmbeddingInput

One item in an embedding request was blank.

Fields

index: usize

Zero-based invalid input index.



DuplicateDocument(DocumentId)

A document identity appeared more than once.



CapabilityDenied

A run did not grant the retriever capability.

Fields

name: String

Retriever name.



Cancelled

The owning run was cancelled.



DeadlineExceeded

The owning run deadline elapsed.



Provider

An embedding provider or retrieval backend failed.

Fields

message: String

Safe provider diagnostic.



UsageOverflow

Retrieval usage counters could not be combined without overflow.

Implementations

Source

impl RetrievalError

pub fn provider(message: impl Into<String>) -> Self

Creates a provider/backend failure without imposing an adapter error representation.